==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/el.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Ημερολόγιο",
    "%s has published the calendar \"%s\"" : "%s δημοσίευσε το ημερολόγιο \"%s\"",
    "Too many redirects. Aborting ..." : "Πάρα πολλές ανακατευθύνσεις. Ματαίωση ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Ο απομακρυσμένος διακομιστής δεν δίνει πρόσβαση στο ημερολόγιο (HTTP {%s} σφάλμα)",
    "Error connecting to remote server" : "Σφάλμα σύνδεσης στον απομακρυσμένο διακομιστή",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Σφάλμα κατά την αίτηση πόρων στον απομακρυσμένο εξυπηρετητή. Αυτό είναι πιθανό να σχετίζεται με αταίριαστο πιστοποιητηκό. ",
    "Error requesting resource on remote server" : "Σφάλμα αιτήματος πόρων στον απομακρυσμένο διακομιστή ",
    "Individual" : "Προσωπικό",
    "Group" : "Ομάδα",
    "Resource" : "Πόρος",
    "Room" : "Δωμάτιο",
    "Unknown" : "Άγνωστο",
    "Required" : "Απαιτείται",
    "Optional" : "Προαιρετικό",
    "Does not attend" : "Μη επαναλαμβανόμενο",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Είστε σε μια άγνωστη ζώνη ώρας ({tz}), επιστροφή πάλι στο UTC",
    "Please create a calendar first." : "Παρακαλώ πρώτα δημιουργήστε ένα ημερολόγιο",
    "New event" : "Νέο συμβάν",
    "CalDAV address for clients" : "Διεύθυνση CalDAV για πελάτες",
    "Error saving WebCal-calendar" : "Σφαλμα αποθήκευσης WebCal-calendar ",
    "WebDAV address for subscriptions" : "WebDAV διευθύνσεις για συνδρομές",
    "EMail has been sent." : "Το e-mail έχει ",
    "There was an issue while sending your EMail." : "Υπήρξε πρόβλημα κατά την αποστολή Email.",
    "group" : "ομάδα",
    "Details" : "Λεπτομέρειες",
    "Attendees" : "Συμμετέχοντες",
    "Reminders" : "Υπενθυμίσεις",
    "Repeating" : "Επαναλαμβανόμενο",
    "When shared show full event" : "Προβολή πλήρους συμβάντος, όταν κοινοποιείται",
    "When shared show only busy" : "Προβολή μόνο απασχολημένων, όταν κοινοποιείται",
    "When shared hide this event" : "Απόκρυψη αυτού του συμβάντος, όταν κοινοποιείται",
    "Confirmed" : "Επιβεβαιώθηκε",
    "Tentative" : "Δοκιμαστικό",
    "Cancelled" : "Ακυρώθηκε",
    "Please add a title!" : "Παρακαλώ προσθέστε τίτλο!",
    "Please select a calendar!" : "Παρακαλώ επιλέξτε ημερολόγιο!",
    "The event ends before it starts!" : "Το γεγονός τελειώνει πριν ξεκινήσει",
    "Global" : "Καθολικό",
    "None" : "Τίποτα",
    "Every day" : "Κάθε μέρα",
    "Every week" : "Κάθε εβδομάδα",
    "Every month" : "Κάθε μήνα",
    "Every year" : "Κάθε χρόνο",
    "never" : "ποτέ",
    "after" : "μετά",
    "At time of event" : "Την ώρα του συνβάντος",
    "5 minutes before" : "πριν 5 λεπτά",
    "10 minutes before" : "πριν 10 λεπτά",
    "15 minutes before" : "πριν 15 λεπτά",
    "30 minutes before" : "πριν 30 λεπτά",
    "1 hour before" : "πριν 1 ώρα",
    "2 hours before" : "πριν 2 ώρες",
    "Custom" : "Προσαρμοσμένο",
    "Audio" : "Ήχος",
    "E Mail" : "E Mail",
    "Pop up" : "Αναδυόμενο",
    "sec" : "δευτ",
    "min" : "ελάχιστη",
    "hours" : "ώρες",
    "days" : "ημέρες",
    "week" : "εβδομάδα",
    "before" : "πριν",
    "start" : "έναρξη",
    "end" : "τέλος",
    "Week {number} of {year}" : "Εβδομάδα {number} του {year}",
    "Successfully imported" : "Εισήχθη επιτυχώς",
    "Audio alarm" : "Ηχητκή ειδοποίηση",
    "Pop-up" : "Αναδυόμενο",
    "E-Mail" : "Ηλεκτρονική αλληλογραφία",
    "{type} {time} before the event starts" : "{type} {time} πριν την έναρξη του συμβάντος",
    "{type} {time} before the event ends" : "{type} {time} πριν τη λήξη του συμβάντος",
    "{type} {time} after the event starts" : "{type} {time} μετά την έναρξη του συμβάντος",
    "{type} {time} after the event ends" : "{type} {time} μετά τη λήξη του συμβάντος",
    "Please enter a valid WebCal-URL" : "Παρακαλούμε εισάγετε έγκυρο WebCal-URL",
    "Title of the Event" : "Τίτλος συμβάντος",
    "All day Event" : "Ολοήμερο συμβάν",
    "Delete" : "Διαγραφή",
    "Cancel" : "Άκυρο",
    "More ..." : "Περισσότερα ...",
    "Create" : "Δημιουργία",
    "Update" : "Ενημέρωση",
    "Close" : "Κλείσιμο",
    "Location" : "Τοποθεσία",
    "Description" : "Περιγραφή",
    "Event status" : "Κατάσταση συμβάντος",
    "Visibility when sharing" : "Ορατότητα κατά τον διαμοιρασμό",
    "Export" : "Εξαγωγή",
    "Click here to access it" : "Κάντε κλικ εδώ για πρόσβαση",
    "Cheers!" : "Με εκτίμηση!",
    "Day" : "Ημέρα",
    "Week" : "Εβδομάδα",
    "Month" : "Μήνας",
    "Today" : "Σήμερα",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Μερικά συμβάντα σε αυτό το ημερολόγιο δεν λειτουργούν Παρακαλούμε ελέγξτε την κονσόλα JS για περισσότερες πληροφορίες.",
    "Share Calendar" : "Διαμοιράστε ένα ημερολόγιο",
    "Shared" : "Κοινόχρηστα",
    "More" : "Περισσότερα",
    "Edit" : "Επεξεργασία",
    "Link" : "Σύνδεσμος",
    "iCal link" : "Σύνδεσμος iCal",
    "Download" : "Λήψη",
    "Share with users or groups" : "Διαμοιρασμός με χρήστες ή ομάδες",
    "can edit" : "δυνατότητα επεξεργασίας",
    "Share link" : "Διαμοιρασμός συνδέσμου",
    "Public access" : "Δημόσια πρόσβαση",
    "Email link to person" : "Αποστολή συνδέσμου με ηλεκτρονικό ταχυδρομείο",
    "Send" : "Αποστολή",
    "New Calendar" : "Νέο Ημερολόγιο",
    "Name" : "Όνομα",
    "New Subscription" : "Νέα συνδρομή",
    "Calendar does not exist" : "Το ημερολόγιο δεν υπάρχει",
    "Maybe you got a wrong link or the calendar was unshared?" : "Μπορεί να έχετε λανθασμένο σύνδεσμο ή έχει αναιρεθεί ο διαμοιρασμός του ημερολογίου;",
    "Edit event" : "Επεξεργασία συμβάντος",
    "Delete Event" : "Διαγραφή συμβάντος",
    "Save Event" : "Αποθήκευση συμβάντος",
    "Time" : "Ώρα",
    "Type" : "Τύπος",
    "Repeat" : "Επανάληψη",
    "times every" : "φορές κάθε",
    "Add" : "Προσθήκη",
    "from" : "από",
    "to" : "προς",
    "Repeat every ..." : "Επανάληψη κάθε ...",
    "end repeat ..." : "τέλος επανάληψης ...",
    "times" : "φορές",
    "Import Calendars" : "Εισαγωγή ημερολογίων",
    "Import canceled" : "Ακύρωση εισαγωγής",
    "Analyzing calendar" : "Ανάλυση ημερολογίου",
    "New calendar" : "Νέο ημερολόγιο",
    "File is empty" : "Το αρχείο είναι άδειο",
    "Settings & import" : "Ρυθμίσεις & εισαγωγή",
    "Show week numbers" : "Εμφάνιση αριθμού εβδομάδας",
    "Import calendar" : "Εισαγωγή ημερολογίου",
    "No Calendars selected for import" : "Δεν επιλέχτηκαν ημερολόγια προς εισαγωγή",
    "Primary CalDAV address" : "Κύρια διεύθυνση CalDAV",
    "iOS/OS X CalDAV address" : "Διεύθυνση CalDAV για iOS/OS X",
    "Subscribe" : "Εγγραφή"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/el.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Ημερολόγιο",
    "%s has published the calendar »%s«" : "%s δημοσίευσε το ημερολόγιο »%s«",
    "Hello," : "Γεια σας,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Θα θέλαμε να σας πληροφορήσουμε ότι  ο χρήστης %s δημοσίευσε το ημερολόγιο »%s«.",
    "Open »%s«" : "Άνοιγμα »%s«",
    "Cheers!" : "Με εκτίμηση!",
    "Recipient" : "Παραλήπτης",
    "Too many redirects. Aborting ..." : "Πάρα πολλές ανακατευθύνσεις. Ματαίωση ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Ο απομακρυσμένος διακομιστής δεν δίνει πρόσβαση στο ημερολόγιο (HTTP {%s} σφάλμα)",
    "Error connecting to remote server" : "Σφάλμα σύνδεσης στον απομακρυσμένο διακομιστή",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Σφάλμα κατά την αίτηση πόρων στον απομακρυσμένο εξυπηρετητή. Αυτό είναι πιθανό να σχετίζεται με αταίριαστο πιστοποιητηκό. ",
    "Error requesting resource on remote server" : "Σφάλμα αιτήματος πόρων στον απομακρυσμένο διακομιστή ",
    "Individual" : "Προσωπικό",
    "Group" : "Ομάδα",
    "Resource" : "Πόρος",
    "Room" : "Δωμάτιο",
    "Unknown" : "Άγνωστο",
    "Required" : "Απαιτείται",
    "Optional" : "Προαιρετικό",
    "Does not attend" : "Δεν παρευρίσκεται",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Είστε σε μια άγνωστη ζώνη ώρας ({tz}), επιστροφή πάλι στο UTC",
    "Please create a calendar first." : "Παρακαλώ πρώτα δημιουργήστε ένα ημερολόγιο",
    "New event" : "Νέο συμβάν",
    "CalDAV address for clients" : "Διεύθυνση CalDAV για πελάτες",
    "Error saving WebCal-calendar" : "Σφαλμα αποθήκευσης WebCal-calendar ",
    "WebDAV address for subscriptions" : "WebDAV διευθύνσεις για συνδρομές",
    "Email has been sent." : "Το Email απεστάλη.",
    "There was an issue while sending your email." : "Υπήρξε πρόβλημα κατά την αποστολή του email. ",
    "group" : "ομάδα",
    "Details" : "Λεπτομέρειες",
    "Attendees" : "Συμμετέχοντες",
    "Reminders" : "Υπενθυμίσεις",
    "Repeating" : "Επαναλαμβανόμενο",
    "When shared show full event" : "Προβολή πλήρους συμβάντος, όταν κοινοποιείται",
    "When shared show only busy" : "Προβολή μόνο απασχολημένων, όταν κοινοποιείται",
    "When shared hide this event" : "Απόκρυψη αυτού του συμβάντος, όταν κοινοποιείται",
    "Confirmed" : "Επιβεβαιώθηκε",
    "Tentative" : "Δοκιμαστικό",
    "Cancelled" : "Ακυρώθηκε",
    "Please add a title." : "Παρακαλώ προσθέστε τίτλο.",
    "Please select a calendar." : "Παρακαλώ επιλέξτε ημερολόγιο.",
    "The event can not end before it starts." : "Το γεγονός δεν μπορεί να τελειώνει πριν ξεκινήσει.",
    "Global" : "Καθολικό",
    "None" : "Τίποτα",
    "Every day" : "Κάθε μέρα",
    "Every week" : "Κάθε εβδομάδα",
    "Every month" : "Κάθε μήνα",
    "Every year" : "Κάθε χρόνο",
    "never" : "ποτέ",
    "after" : "μετά",
    "How about getting started by importing some calendars?" : "Τι θα λέγατε να ξεκινήσετε εισάγοντας μερικά ημερολόγια;",
    "At time of event" : "Την ώρα του συνβάντος",
    "5 minutes before" : "πριν 5 λεπτά",
    "10 minutes before" : "πριν 10 λεπτά",
    "15 minutes before" : "πριν 15 λεπτά",
    "30 minutes before" : "πριν 30 λεπτά",
    "1 hour before" : "πριν 1 ώρα",
    "2 hours before" : "πριν 2 ώρες",
    "Custom" : "Προσαρμοσμένο",
    "Audio" : "Ήχος",
    "Email" : "Email",
    "Pop-up" : "Αναδυόμενο",
    "sec" : "δευτ",
    "min" : "ελάχιστη",
    "hours" : "ώρες",
    "days" : "ημέρες",
    "week" : "εβδομάδα",
    "before" : "πριν",
    "start" : "έναρξη",
    "end" : "τέλος",
    "Editing reminders of unknown type not supported." : "Δεν υποστηρίζεται η επεξεργασία υπενθυμίσεων άγνωστου τύπου.",
    "Week {number} of {year}" : "Εβδομάδα {number} του {year}",
    "Successfully imported" : "Εισήχθη επιτυχώς",
    "Partially imported, 1 failure" : "Μερική εισαγωγή, 1 αποτυχία",
    "Partially imported, {n} failures" : "Μερική εισαγωγή, {n} αποτυχίες",
    "Audio alarm" : "Ηχητκή ειδοποίηση",
    "{type} {time} before the event starts" : "{type} {time} πριν την έναρξη του συμβάντος",
    "{type} {time} before the event ends" : "{type} {time} πριν τη λήξη του συμβάντος",
    "{type} {time} after the event starts" : "{type} {time} μετά την έναρξη του συμβάντος",
    "{type} {time} after the event ends" : "{type} {time} μετά τη λήξη του συμβάντος",
    "{type} at the event's start" : "{type} στην έναρξη του γεγονότος",
    "{type} at the event's end" : "{type} στο τέλος του γεγονότος",
    "{type} at {time}" : "{type} στις {time}",
    "{calendar} shared by {owner}" : "Διαμοιρασμός {calendar} από {owner}",
    "Please enter a valid WebCal-URL" : "Παρακαλούμε εισάγετε έγκυρο WebCal-URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Σοβαρό σφάλμα στον διαμεσολαβητή webcal. Παρακαλούμε επικοινωνήστε με τον διαχειριστή για περισσότερες πληροφορίες.",
    "Title of the Event" : "Τίτλος συμβάντος",
    "Starts" : "Ξεκινά",
    "Ends" : "Τελειώνει",
    "All day Event" : "Ολοήμερο συμβάν",
    "Delete" : "Διαγραφή",
    "Cancel" : "Άκυρο",
    "More ..." : "Περισσότερα ...",
    "Create" : "Δημιουργία",
    "Update" : "Ενημέρωση",
    "Close" : "Κλείσιμο",
    "Location" : "Τοποθεσία",
    "Description" : "Περιγραφή",
    "Event status" : "Κατάσταση συμβάντος",
    "Visibility when sharing" : "Ορατότητα κατά τον διαμοιρασμό",
    "Export" : "Εξαγωγή",
    "%s has published the calendar %s" : "%sέχει δημοσιεύσει το ημερολόγιο%s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Θα θέλαμε να σας πληροφορήσουμε ότι %sέχει δημοσιευτεί από το ημερολόγιο {boldstart}%s{boldend}.",
    "Click here to access it" : "Κάντε κλικ εδώ για πρόσβαση",
    "We wanted to inform you that %s has published the calendar %s." : "Θα θέλαμε να σας πληροφορήσουμε ότι ο χρήστης %s δημοσίευσε το ημερολόγιο %s.",
    "Click on the link below to access it" : "Κάντε κλικ εδώ για να αποκτήσετε πρόσβαση",
    "Day" : "Ημέρα",
    "Week" : "Εβδομάδα",
    "Month" : "Μήνας",
    "Today" : "Σήμερα",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Μερικά συμβάντα σε αυτό το ημερολόγιο δεν λειτουργούν. Παρακαλούμε ελέγξτε την κονσόλα JS για περισσότερες πληροφορίες.",
    "Share Calendar" : "Διαμοιράστε ένα ημερολόγιο",
    "Shared" : "Κοινόχρηστα",
    "More" : "Περισσότερα",
    "Edit" : "Επεξεργασία",
    "Link" : "Σύνδεσμος",
    "iCal link" : "Σύνδεσμος iCal",
    "Download" : "Λήψη",
    "Share with users or groups" : "Διαμοιρασμός με χρήστες ή ομάδες",
    "can edit" : "δυνατότητα επεξεργασίας",
    "Share link" : "Διαμοιρασμός συνδέσμου",
    "Public access" : "Δημόσια πρόσβαση",
    "Email link to person" : "Αποστολή συνδέσμου με ηλεκτρονικό ταχυδρομείο",
    "Send" : "Αποστολή",
    "New Calendar" : "Νέο Ημερολόγιο",
    "Name" : "Όνομα",
    "New Subscription" : "Νέα συνδρομή",
    "Go back" : "Πίσω",
    "Go forward" : "Μπροστά",
    "Calendar does not exist" : "Το ημερολόγιο δεν υπάρχει",
    "Maybe you got a wrong link or the calendar was unshared?" : "Μπορεί να έχετε λανθασμένο σύνδεσμο ή έχει αναιρεθεί ο διαμοιρασμός του ημερολογίου;",
    "Edit event" : "Επεξεργασία συμβάντος",
    "Delete Event" : "Διαγραφή συμβάντος",
    "Save Event" : "Αποθήκευση συμβάντος",
    "Time" : "Ώρα",
    "Type" : "Τύπος",
    "Relative" : "Σχετικό",
    "Absolute" : "Απόλυτο",
    "Repeat" : "Επανάληψη",
    "times every" : "φορές κάθε",
    "Add" : "Προσθήκη",
    "Email address of attendee" : "Διεύθυνση ηλεκτρονικής αλληλογραφίας συμμετέχοντος",
    "Please add your email address in the personal settings in order to add attendees." : "Παρακαλώ προσθέστε τη διεύθυνση ηλεκτρονικής αλληλογραφίας σας στις προσωπικές ρυθμίσεις για να προσθέσετε συμμετέχοντες.",
    "from" : "από",
    "to" : "προς",
    "This event's repeating rule is not supported yet." : "Ο κανόνας επανάληψης γεγονότων δεν υποστηρίζεται ακόμα.",
    "Support for advanced rules will be added with subsequent updates." : "Η υποστήριξη κανόνων για προχωρημένους θα προστεθεί με τις επόμενες ενημερώσεις.",
    "Reset repeating rule" : "Επαναφορά επαναλαμβανόμενου κανόνα",
    "Repeat every ..." : "Επανάληψη κάθε ...",
    "end repeat ..." : "τέλος επανάληψης ...",
    "times" : "φορές",
    "Import Calendars" : "Εισαγωγή ημερολογίων",
    "Import canceled" : "Ακύρωση εισαγωγής",
    "Analyzing calendar" : "Ανάλυση ημερολογίου",
    "The file contains objects incompatible with the selected calendar" : "Το αρχείο περιέχει αντικείμενα ασύμβατα με το επιλεγμένο ημερολόγιο",
    "New calendar" : "Νέο ημερολόγιο",
    "File is empty" : "Το αρχείο είναι άδειο",
    "Import scheduled" : "Η εισαγωγή προγραμματίστηκε",
    "%s shared the calendar <strong>%s</strong> with you" : "Ο %sμοιράστηκε το ημερολόγιο <strong>%s</strong>με εσάς",
    "Embed" : "Ενσωμάτωση",
    "Iframe to integrate" : "Iframe προς ενσωμάτωση",
    "Publish URL" : "Δημοσίευση URL",
    "Settings & import" : "Ρυθμίσεις & εισαγωγή",
    "Skip simple event editor" : "Παράλειψη απλού επεξεργαστή γεγονότων",
    "Show week numbers" : "Εμφάνιση αριθμού εβδομάδας",
    "Import calendar" : "Εισαγωγή ημερολογίου",
    "No Calendars selected for import" : "Δεν επιλέχτηκαν ημερολόγια προς εισαγωγή",
    "Primary CalDAV address" : "Κύρια διεύθυνση CalDAV",
    "iOS/OS X CalDAV address" : "Διεύθυνση CalDAV για iOS/OS X",
    "Subscribe" : "Εγγραφή"
},
"nplurals=2; plural=(n != 1);");
